///////////////////////////////////////////////////////////////////////////////
//
//    File Name:  ProductVersion.h
//
//  Description:  Header file for ProductVersion.rul
//
//     Comments:  #include this file (ProductVersion.h) around the top of
//                Setup.rul (where the other header files are included) and
//                this file's corresponding rul file (ProductVersion.rul) at
//                the end.
//
//       Author:  Mickey Ferguson, Plant Equipment, Inc. (mferguson@peinc.com)
//
//          Mod:  Rich Brady, TBA LabSystems Limited (rich.brady@labsystems.com)
//                - Adapted for compilation on IS6.1
//                Stefan Krueger (skrueger@installsite.org)
//                - backward compatibility with IS5
//
///////////////////////////////////////////////////////////////////////////////


// for backward compatibility with IS5
#if _ISCRIPT_VER < 0x600
	#define cdecl
	#define BYVAL
#endif

#define MAX_BUF 65535

typedef VS_FIXEDFILEINFO
begin
  LONG dwSignature;
  LONG dwStrucVersion;         //  e.g. 0x00000042 = "0.42"
  LONG dwFileVersionMS;        //  e.g. 0x00030075 = "3.75"
  LONG dwFileVersionLS;        //  e.g. 0x00000031 = "0.31"
  LONG dwProductVersionMS;     //  e.g. 0x00030010 = "3.10"
  LONG dwProductVersionLS;     //  e.g. 0x00000031 = "0.31"
  LONG dwFileFlagsMask;        //  = 0x3F for version "0.42"
  LONG dwFileFlags;            //  e.g. VFF_DEBUG Or VFF_PRERELEASE
  LONG dwFileOS;               //  e.g. VOS_DOS_WINDOWS16
  LONG dwFileType;             //  e.g. VFT_DRIVER
  LONG dwFileSubtype;          //  e.g. VFT2_DRV_KEYBOARD
  LONG dwFileDateMS;           //  e.g. 0
  LONG dwFileDateLS;           //  e.g. 0  
end;


// Windows API calls:
//
// BYREF and BYVAL added to STRING args to eliminate compilation warnings
//
prototype Version.GetFileVersionInfoSizeA(BYREF STRING, BYREF LONG);
prototype Version.GetFileVersionInfoA(BYREF STRING, LONG, LONG, POINTER);
prototype Version.VerQueryValueA(POINTER, BYVAL STRING, BYREF LONG, BYREF LONG);
//
// Added return values.
// Malloc was being passed a POINTER rather than a LONG.
// cdecl calling convention must be specified.
// 
prototype cdecl POINTER Msvcrt.memcpy(POINTER, POINTER, BYVAL LONG);
prototype cdecl POINTER Msvcrt.malloc(BYREF LONG);
prototype cdecl Msvcrt.free(POINTER);    


// provided functions:
prototype VerGetProductVersion(STRING, BYREF STRING);
prototype CalcVersion(LONG, BYREF STRING);
